Module entity

Module entity 

DelayTimer is a cyclic task manager with latency properties, based on an internal event manager and task scheduler, and supported by the runtime provided by smol, which makes it easy to manage asynchronous/synchronous/scripted cyclic tasks.

DelayTimer

User applications can be served through the lib used by DelayTimer:

  1. Mission deployment.

Structs

DelayTimer
DelayTimer is an abstraction layer that helps users solve execution cycle synchronous/asynchronous tasks.
DelayTimerBuilder
Builds DelayTimer with custom configuration values.
SharedHeader
SharedHeader Store the core context of the runtime.

Enums

RuntimeKind
Async-Runtime Kind

Functions

timestamp
get current OS SystemTime.
timestamp_micros
get current OS SystemTime.