DelayTimer is a cyclic task manager with latency properties, based on an internal event manager and task scheduler, and supported by the runtime provided by smol, which makes it easy to manage asynchronous/synchronous/scripted cyclic tasks.
DelayTimer
User applications can be served through the lib used by DelayTimer:
- Mission deployment.
Structs
- Delay
Timer - DelayTimer is an abstraction layer that helps users solve execution cycle synchronous/asynchronous tasks.
- Delay
Timer Builder - Builds DelayTimer with custom configuration values.
- Shared
Header - SharedHeader Store the core context of the runtime.
Enums
- Runtime
Kind - Async-Runtime Kind
Functions
- timestamp
- get current OS SystemTime.
- timestamp_
micros - get current OS SystemTime.