pub enum TimerEvent {
StopTimer,
AddTask(Box<Task>),
InsertTask(Box<Task>, TaskInstancesChainMaintainer),
UpdateTask(Box<Task>),
RemoveTask(u64),
CancelTask(u64, i64),
TimeoutTask(u64, i64),
FinishTask(FinishTaskBody),
AppendTaskHandle(u64, DelayTaskHandlerBox),
AdvanceTask(u64),
}Expand description
Event for Timer Wheel Core.
Variants
StopTimer
Stop the Timer.
AddTask(Box<Task>)
Add a new Task.
InsertTask(Box<Task>, TaskInstancesChainMaintainer)
Insert a new Task.
Maintain a state that is transparent to the user, such as the end of a task running instance.
UpdateTask(Box<Task>)
Update a Task in Timer .
RemoveTask(u64)
Remove a Task in Timer .
CancelTask(u64, i64)
Cancel a Task running instance in Timer .
TimeoutTask(u64, i64)
Cancel a timeout Task running instance in Timer .
FinishTask(FinishTaskBody)
Finished a Task running instance in Timer .
AppendTaskHandle(u64, DelayTaskHandlerBox)
Append a new instance of a running task .
AdvanceTask(u64)
Take the initiative to perform once Task.